aboutsummaryrefslogtreecommitdiff
path: root/src/patch/patch.hh
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-08-06 09:59:55 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-08-06 09:59:55 +0000
commitade49bbd5094250bc5e3b4b68147d01f09f2a3e0 (patch)
tree70b9920dcb528f227e63d12d21784e92474febc9 /src/patch/patch.hh
parent61075aafa5d63acfef28a9760caccd97964a719a (diff)
add patch::symmetry_ghost_zone_on_edge()
for symmetry with patch::interpatch_ghost_zone_on_edge() and because it's useful in patch_system::synchronize_Jacobian() et al git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@684 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/patch.hh')
-rw-r--r--src/patch/patch.hh7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/patch/patch.hh b/src/patch/patch.hh
index 6325dfe..3724188 100644
--- a/src/patch/patch.hh
+++ b/src/patch/patch.hh
@@ -345,8 +345,11 @@ public:
const;
// get ghost zone on specified edge,
- // assert() that it is indeed interpatch,
- // static_cast<> to interpatch_ghost_zone ptr
+ // assert() that it is indeed of the specified type,
+ // static_cast<> to {symmetry,interpatch}_ghost_zone&
+ symmetry_ghost_zone& symmetry_ghost_zone_on_edge
+ (const patch_edge &e)
+ const;
interpatch_ghost_zone& interpatch_ghost_zone_on_edge
(const patch_edge &e)
const;